EXPORTS
	"_._10CAtsLogger" @ 1 NONAME R3UNUSED ; CAtsLogger::~CAtsLogger(void)
	BeginTestCaseL__10CAtsLoggerRC7TDesC16iT1T1 @ 2 NONAME ; CAtsLogger::BeginTestCaseL(TDesC16 const &, int, TDesC16 const &, TDesC16 const &)
	BeginTestCaseReportL__10CAtsLoggerRC7TDesC16T1RC5TTimeT1T1 @ 3 NONAME ; CAtsLogger::BeginTestCaseReportL(TDesC16 const &, TDesC16 const &, TTime const &, TDesC16 const &, TDesC16 const &)
	BeginTestCaseReportL__10CAtsLoggerRC7TDesC16iRC5TTimeT1T1 @ 4 NONAME ; CAtsLogger::BeginTestCaseReportL(TDesC16 const &, int, TTime const &, TDesC16 const &, TDesC16 const &)
	BeginTestReportL__10CAtsLogger @ 5 NONAME R3UNUSED ; CAtsLogger::BeginTestReportL(void)
	BeginTestSetL__10CAtsLoggerRC7TDesC16N31 @ 6 NONAME ; CAtsLogger::BeginTestSetL(TDesC16 const &, TDesC16 const &, TDesC16 const &, TDesC16 const &)
	CloseL__10CAtsLogger @ 7 NONAME R3UNUSED ; CAtsLogger::CloseL(void)
	CommentL__10CAtsLoggerGt11TRefByValue1ZC7TDesC16e @ 8 NONAME ; CAtsLogger::CommentL(TRefByValue<TDesC16 const>,...)
	CommentL__10CAtsLoggerRC7TDesC16 @ 9 NONAME R3UNUSED ; CAtsLogger::CommentL(TDesC16 const &)
	ContinueAfterRebootL__10CAtsLogger @ 10 NONAME R3UNUSED ; CAtsLogger::ContinueAfterRebootL(void)
	DebugL__10CAtsLoggerGt11TRefByValue1ZC7TDesC16e @ 11 NONAME ; CAtsLogger::DebugL(TRefByValue<TDesC16 const>,...)
	DebugL__10CAtsLoggerRC7TDesC16 @ 12 NONAME R3UNUSED ; CAtsLogger::DebugL(TDesC16 const &)
	DebugOutput__10CAtsLoggerRC7TDesC16 @ 13 NONAME R3UNUSED ; CAtsLogger::DebugOutput(TDesC16 const &)
	EndTestCaseL__10CAtsLogger @ 14 NONAME R3UNUSED ; CAtsLogger::EndTestCaseL(void)
	EndTestReportL__10CAtsLogger @ 15 NONAME R3UNUSED ; CAtsLogger::EndTestReportL(void)
	EndTestSetL__10CAtsLogger @ 16 NONAME R3UNUSED ; CAtsLogger::EndTestSetL(void)
	ErrorL__10CAtsLoggerGt11TRefByValue1ZC7TDesC16e @ 17 NONAME ; CAtsLogger::ErrorL(TRefByValue<TDesC16 const>,...)
	ErrorL__10CAtsLoggerRC7TDesC16 @ 18 NONAME R3UNUSED ; CAtsLogger::ErrorL(TDesC16 const &)
	ErrorMessage__10CAtsLoggerRCi @ 19 NONAME R3UNUSED ; CAtsLogger::ErrorMessage(int const &)
	IsValid__10CAtsLogger @ 20 NONAME R3UNUSED ; CAtsLogger::IsValid(void)
	NewL__10CAtsLoggerRC7TDesC16i @ 21 NONAME R3UNUSED ; CAtsLogger::NewL(TDesC16 const &, int)
	RawLogL__10CAtsLoggerGt11TRefByValue1ZC7TDesC16e @ 22 NONAME ; CAtsLogger::RawLogL(TRefByValue<TDesC16 const>,...)
	RawLogL__10CAtsLoggerRC7TDesC16 @ 23 NONAME R3UNUSED ; CAtsLogger::RawLogL(TDesC16 const &)
	SaveForRebootL__10CAtsLogger @ 24 NONAME R3UNUSED ; CAtsLogger::SaveForRebootL(void)
	SetDebugOutput__10CAtsLoggeri @ 25 NONAME R3UNUSED ; CAtsLogger::SetDebugOutput(int)
	SetFullReporting__10CAtsLoggeri @ 26 NONAME R3UNUSED ; CAtsLogger::SetFullReporting(int)
	SetIndentation__10CAtsLoggeri @ 27 NONAME R3UNUSED ; CAtsLogger::SetIndentation(int)
	SetTestCaseResultL__10CAtsLoggerRC7TDesC16 @ 28 NONAME R3UNUSED ; CAtsLogger::SetTestCaseResultL(TDesC16 const &)
	SetTestCaseResultL__10CAtsLoggeri @ 29 NONAME R3UNUSED ; CAtsLogger::SetTestCaseResultL(int)
	TestCaseFailed__10CAtsLogger @ 30 NONAME R3UNUSED ; CAtsLogger::TestCaseFailed(void)
	TestCaseNa__10CAtsLogger @ 31 NONAME R3UNUSED ; CAtsLogger::TestCaseNa(void)
	TestCasePassed__10CAtsLogger @ 32 NONAME R3UNUSED ; CAtsLogger::TestCasePassed(void)
	TestCaseSkipped__10CAtsLogger @ 33 NONAME R3UNUSED ; CAtsLogger::TestCaseSkipped(void)
	WarningL__10CAtsLoggerGt11TRefByValue1ZC7TDesC16e @ 34 NONAME ; CAtsLogger::WarningL(TRefByValue<TDesC16 const>,...)
	WarningL__10CAtsLoggerRC7TDesC16 @ 35 NONAME R3UNUSED ; CAtsLogger::WarningL(TDesC16 const &)
	BeginTestCaseL__10CAtsLoggerRC7TDesC16N31 @ 36 NONAME ; CAtsLogger::BeginTestCaseL(TDesC16 const &, TDesC16 const &, TDesC16 const &, TDesC16 const &)

